==========
Simulation
==========

.. currentmodule:: rgrow

-------------------
Running simulations
-------------------

.. autosummary::
    :toctree: api/

    Simulation
    Simulation.evolve
    Simulation.evolve_all

---------------------------------------------
Modifying simulations and getting information
---------------------------------------------

.. autosummary::
    :toctree: api/

    Simulation.add_state
    Simulation.add_n_states
    Simulation.set_system_param
    Simulation.get_system_param
    Simulation.canvas_copy
    Simulation.canvas_view
    Simulation.tile_concs
    Simulation.tile_stoics
    Simulation.tile_names
    Simulation.state_events
    Simulation.state_time
    Simulation.state_ntiles